@@ -31,7 +31,7 @@ simulate_mml <- function(object, iIndex = NULL, theta = NULL, nobs = NULL, ...){
     t.mean <- object$beta
     t.sigma <- object$variance
     if(ndim == 1){
-      theta <- rnorm(nnodes, mean = t.mean, sd = sqrt(t.sigma))  
+      theta <- stats::rnorm(nnodes, mean = t.mean, sd = sqrt(t.sigma))  
     } else {
       theta <- MASS::mvrnorm(nnodes, mu = t.mean, Sigma = t.sigma)
     }  
@@ -50,13 +50,13 @@ simulate_mml <- function(object, iIndex = NULL, theta = NULL, nobs = NULL, ...){
   nnodes <- nrow(theta)
   
   #****
-  # calculate p
+  # calculate probs
   p <- IRT.irfprob(object = class(object), A = A, B = B, xsi = xsi, theta = theta,
                    guess = guess, nnodes = nnodes, iIndex = iIndex, maxK = maxK, ... )
   
   #****
   # simulate data
-  res <- matrix(runif(nnodes * nI), nrow = nnodes, ncol = nI)
+  res <- matrix( stats::runif(nnodes * nI), nrow = nnodes, ncol = nI)
   for(ii in 1:nI){
     cat.success.ii <- (res[, ii] > t(apply(p[ii, , ], 2, cumsum)))
     res[, ii] <-  c(cat.success.ii %*% rep(1, maxK))
