@@ -65,15 +65,15 @@ function( object , file = NULL , ...){
     cat( "    Regression parameters      = " , object$ic$Nparsbeta , "\n" )    	
     cat( "    (Co)Variance parameters    = " , object$ic$Nparscov , "\n\n" )    		
 	
-    cat( "AIC  = " , round( object$ic$AIC , 2 ) , " | penalty =" , round( object$ic$AIC - object$ic$deviance ,2 ) , 
+    cat( "AIC  = " , round( object$ic$AIC , 0 ) , " | penalty =" , round( object$ic$AIC - object$ic$deviance ,2 ) , 
 			"   | AIC = -2*LL + 2*p  \n" )    
-    cat( "AICc = " , round( object$ic$AICc , 2 ) ," | penalty =" , round( object$ic$AICc - object$ic$deviance ,2 ) )
+    cat( "AICc = " , round( object$ic$AICc , 0 ) ," | penalty =" , round( object$ic$AICc - object$ic$deviance ,2 ) )
 		cat("    | AICc = -2*LL + 2*p + 2*p*(p+1)/(n-p-1)  (bias corrected AIC)\n" )   	
-    cat( "BIC  = " , round( object$ic$BIC , 2 ) , " | penalty =" , round( object$ic$BIC - object$ic$deviance ,2 ) , 
+    cat( "BIC  = " , round( object$ic$BIC , 0 ) , " | penalty =" , round( object$ic$BIC - object$ic$deviance ,2 ) , 
 			"   | BIC = -2*LL + log(n)*p  \n" )  
-    cat( "aBIC  = " , round( object$ic$aBIC , 2 ) , " | penalty =" , round( object$ic$aBIC - object$ic$deviance ,2 ) , 
+    cat( "aBIC  = " , round( object$ic$aBIC , 0 ) , " | penalty =" , round( object$ic$aBIC - object$ic$deviance ,2 ) , 
 			"   | aBIC = -2*LL + log((n-2)/24)*p  (adjusted BIC) \n" ) 
-    cat( "CAIC = " , round( object$ic$CAIC , 2 ) ," | penalty =" , round( object$ic$CAIC - object$ic$deviance ,2 ) )
+    cat( "CAIC = " , round( object$ic$CAIC , 0 ) ," | penalty =" , round( object$ic$CAIC - object$ic$deviance ,2 ) )
 		cat("   | CAIC = -2*LL + [log(n)+1]*p  (consistent AIC)\n\n" )   
 
 	cat("------------------------------------------------------------\n")
@@ -97,7 +97,7 @@ function( object , file = NULL , ...){
 		if ( object$G >1){
 			obji <- sqrt( object$variance )
 					} else {
-		obji <- cov2cor(object$variance)
+		obji <- stats::cov2cor(object$variance)
 		diag(obji) <- sqrt( diag( object$variance) )
 					}
 		if ( object$G >1){
